@@ -44,6 +44,7 @@ def main(arguments=None):
 
     addDebugSystem(args.debug)
 
+
     if args.remove==True:
             for language in ['es', 'en']:
                 remove_without_errors(f"unogenerator_documentation_{language}.odt")
@@ -135,6 +136,9 @@ def demo_ods_standard(language, port=2002, suffix="",):
     doc.createSheet("Styles")
     doc.setColumnsWidth([3.5, 5, 2, 2, 2, 2, 2, 5, 5, 3, 3])
     
+    
+    doc.setCellName("A1",  "MYNAME")
+    
     doc.addCellWithStyle("A1", _("Style name"), ColorsNamed.Orange, "BoldCenter")
     doc.addCellWithStyle("B1", _("Date and time"), ColorsNamed.Orange, "BoldCenter")
     doc.addCellWithStyle("C1", _("Date"), ColorsNamed.Orange, "BoldCenter")
@@ -230,6 +234,8 @@ def demo_odt_standard(language, port=2002, suffix=""):
         _(f"This file have been generated with UnoGenerator-{__version__}. You can see UnoGenerator main page in http://github.com/turulomio/unogenerator"), 
         ["unogenerator", "demo", "files"]
     )
+    
+    
     doc.addParagraph(_("UnoGenerator documentation"), "Title")
     doc.addParagraph(_(f"Version: {__version__}"), "Subtitle")
     
@@ -347,19 +353,19 @@ doc=ODT()"""    , "Code")
     
     l=[]
     l.append( _("Este es un ejemplo de imagen as char: "))
-    l.append(doc.textcontentImage(resource_filename(__name__, 'images/crown.png'), 1000, 1000, "AS_CHARACTER"))
+    l.append(doc.textcontentImage(resource_filename(__name__, 'images/crown.png'), 1, 1, "AS_CHARACTER", "PRIMERA", linked=True))
     l.append(". Ahora sigo escribiendo sin problemas.")
     doc.addParagraphComplex(l, "Standard")
 
     l=[]
     l.append( _("As you can see, I can reuse it one hundred times. File size will not be increased because I used reference names."))
     for i in range(100):
-        l.append(doc.textcontentImage(resource_filename(__name__, 'images/crown.png'), 500, 500, "AS_CHARACTER"))
+        l.append(doc.textcontentImage(resource_filename(__name__, 'images/crown.png'), 0.5,  0.5, "AS_CHARACTER", linked=True))
     doc.addParagraphComplex(l, "Standard")
 
 
     doc.addParagraph(_("The next paragraph is generated with the illustration method"), "Standard")
-    doc.addImageParagraph([resource_filename(__name__, 'images/crown.png')]*5, 2500, 1500, "Illustration")
+    doc.addImageParagraph([resource_filename(__name__, 'images/crown.png')]*5, 2.5, 1.5, "Illustration", linked=True)
 
 
     doc.addParagraph(_("Search and Replace"), "Heading 2")
